@@ -4,19 +4,16 @@
 This module provides the main GRL class and utility functions
 """
 
-USE_LXML = True
-try:
+from .info import USE_LXML, USE_YAML
+
+if USE_LXML:
     import lxml.etree as ET
-except ImportError:
+else:
     import xml.etree.ElementTree as ET
     import xml.dom.minidom as minidom
-    USE_LXML = False
 
-USE_YAML = True
-try:
+if USE_YAML:
     import yaml
-except ImportError:
-    USE_YAML = False
 
 import os
 import copy
@@ -174,6 +171,8 @@ class GRL(object):
         'cut'
     ]
 
+    ROOT_PATTERN = re.compile('\.root(\..+)?:/')
+
     def __init__(self, grl=None, from_string=False):
         """
         *grl*: [ dict | str | None ]
@@ -203,7 +202,7 @@ class GRL(object):
                 if grl.startswith("http://"):
                     grl = urllib2.urlopen(grl)
                 # is grl a ROOT file path?
-                elif re.search('.root:/', grl):
+                elif re.search(self.ROOT_PATTERN, grl):
                     # one place where goodruns requires ROOT
                     try:
                         import ROOT
@@ -213,7 +212,7 @@ class GRL(object):
                                           'but cannot import ROOT. Are ROOT '
                                           'and PyROOT installed?')
                     cwd = ROOT.gDirectory
-                    filename, _, path = grl.partition(':/')
+                    filename, _, path = grl.rpartition(':/')
                     root_file = ROOT.TFile.Open(filename)
                     if not root_file:
                         raise IOError('Could not open ROOT file: %s' %
@@ -674,7 +673,7 @@ class GRL(object):
         *name*: str
         """
         # is name a ROOT file path?
-        if re.search('.root:/', name):
+        if re.search(self.ROOT_PATTERN, name):
             # one place where goodruns requires ROOT
             try:
                 import ROOT
@@ -684,7 +683,7 @@ class GRL(object):
                                   'but cannot import ROOT. Are ROOT and PyROOT '
                                   'installed?')
             cwd = ROOT.gDirectory
-            filename, _, path = name.partition(':/')
+            filename, _, path = name.rpartition(':/')
             root_file = ROOT.TFile.Open(filename, 'UPDATE')
             if not root_file:
                 raise IOError('Could not open ROOT file: %s' %
